# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)

BEGIN { $| = 1; print "1..8\n"; }
END {print "not ok 1\n" unless $loaded;}
use Apache::Htaccess;
$loaded = 1;
print "ok 1\n";

######################### End of black magic.

# Insert your test code below (better if it prints "ok 13"
# (correspondingly "not ok 13") depending on the success of chunk 13
# of the test code):


my $obj = Apache::Htaccess->new("htaccess");
if($obj) {
	print "ok 2\n";
} else {
	print "not ok 2\n";
}

if($obj->global_requires('admin','0','1')) { print "ok 3\n"; }
else { print "not ok 3\n"; }

if($obj->directives('CheckSpelling' => 'on')) { print "ok 4\n"; }
else { print "not ok 4\n"; }

if($obj->requires('admin.cgi','admin','3')) { print "ok 5\n"; }
else { print "not ok 5\n"; }

if($obj->save()) { print "ok 6\n"; }
else { print "not ok 6\n"; }

if(-e 'htaccess') { print "ok 7\n"; }
else { print "not ok 7\n"; }

if( (stat('htaccess'))[7] > 0 ) { print "ok 8\n"; }
else { print "not ok 8\n"; }

